==> youtubedl-gui_4.4.orig.tar.xz: youtubedl-gui-4.4/locales/ytdl-gui_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>QCoreApplication</name>
    <message>
        <source>Youtube Downloader</source>
        <translation>Téléchargeur de vidéos</translation>
    </message>
    <message>
        <source>Select a folder</source>
        <translation>Sélectionnez un dossier</translation>
    </message>
    <message>
        <source>Cancel download in progress?</source>
        <translation>Annuler le téléchargement en cours ?</translation>
    </message>
    <message>
        <source>Saving and converting...</source>
        <translation>Enregistrement et conversion...</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Progression</translation>
    </message>
    <message>
        <source>Invalid argument in config file:</source>
        <translation>Erreur dans le fichier de configuration:</translation>
    </message>
    <message>
        <source>invalid argument</source>
        <translation>Argument invalide</translation>
    </message>
    <message>
        <source>out of range</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>undefined error</source>
        <translation>Erreur non définie</translation>
    </message>
    <message>
        <source>Invalid argument in config file</source>
        <translation>Erreur dans le fichier de configuration</translation>
    </message>
    <message>
        <source>Download Succeeded</source>
        <translation>Téléchargement effectué</translation>
    </message>
    <message>
        <source>Download succeded</source>
        <translation type="vanished">Téléchargement effectué</translation>
    </message>
    <message>
        <source>[INFO] Yt-dlp command: </source>
        <translation>[INFO] Commande de yt-dlp&#xa0;: </translation>
    </message>
    <message>
        <source>[ERROR] QProcess failed with error code: </source>
        <translation>[ERROR] Le QProcess a échoué avec le code d’erreur&#xa0;: </translation>
    </message>
    <message>
        <source>Failed! Recheck input for errors. If the url you provided is correct, try with other resolutions or formats.</source>
        <translation>Le téléchargement a échoué. Si l’URL que vous avez fournie est correcte, réessayez avec d’autres résolutions ou formats.</translation>
    </message>
</context>
<context>
    <name>downloadStatus</name>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloading...</source>
        <translation>Téléchargement...</translation>
    </message>
</context>
<context>
    <name>ytdl</name>
    <message>
        <source>ytdl</source>
        <translation>ytdl</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Music&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Qualité:</translation>
    </message>
    <message>
        <source>Best</source>
        <translation>Meilleure</translation>
    </message>
    <message>
        <source>Good</source>
        <translation>Bonne</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Moyenne</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Basse</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <source>AAC</source>
        <translation>AAC</translation>
    </message>
    <message>
        <source>OGG</source>
        <translation>OGG</translation>
    </message>
    <message>
        <source>MP3</source>
        <translation>MP3</translation>
    </message>
    <message>
        <source>OPUS</source>
        <translation>OPUS</translation>
    </message>
    <message>
        <source>WAV</source>
        <translation>WAV</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vidéo</translation>
    </message>
    <message>
        <source>Max Resolution:</source>
        <translation>Résolution max:</translation>
    </message>
    <message>
        <source>4K</source>
        <translation>4K</translation>
    </message>
    <message>
        <source>1440p</source>
        <translation>1440p</translation>
    </message>
    <message>
        <source>1080p</source>
        <translation>1080p</translation>
    </message>
    <message>
        <source>720p</source>
        <translation>720p</translation>
    </message>
    <message>
        <source>480p</source>
        <translation>480p</translation>
    </message>
    <message>
        <source>360p</source>
        <translation>360p</translation>
    </message>
    <message>
        <source>Preferred Format:</source>
        <translation>Format préféré:</translation>
    </message>
    <message>
        <source>3GP</source>
        <translation>3GP</translation>
    </message>
    <message>
        <source>FLV</source>
        <translation>FLV</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>WEBM</source>
        <translation>WEBM</translation>
    </message>
    <message>
        <source>Enter URL:</source>
        <translation>Entrez l’URL:</translation>
    </message>
    <message>
        <source>Playlist</source>
        <translation>Playlist</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>Sélectionner le dossier...</translation>
    </message>
    <message>
        <source>Defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Télécharger</translation>
    </message>
</context>
</TS>

==> youtubedl-gui_4.4.1.orig.tar.xz: youtubedl-gui-4.4.1/locales/ytdl-gui_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>QCoreApplication</name>
    <message>
        <source>Youtube Downloader</source>
        <translation>Téléchargeur de vidéos</translation>
    </message>
    <message>
        <source>Select a folder</source>
        <translation>Sélectionnez un dossier</translation>
    </message>
    <message>
        <source>Cancel download in progress?</source>
        <translation>Annuler le téléchargement en cours ?</translation>
    </message>
    <message>
        <source>Saving and converting...</source>
        <translation>Enregistrement et conversion...</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Progression</translation>
    </message>
    <message>
        <source>Invalid argument in config file:</source>
        <translation>Erreur dans le fichier de configuration:</translation>
    </message>
    <message>
        <source>invalid argument</source>
        <translation>Argument invalide</translation>
    </message>
    <message>
        <source>out of range</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>undefined error</source>
        <translation>Erreur non définie</translation>
    </message>
    <message>
        <source>Invalid argument in config file</source>
        <translation>Erreur dans le fichier de configuration</translation>
    </message>
    <message>
        <source>Download Succeeded</source>
        <translation>Téléchargement effectué</translation>
    </message>
    <message>
        <source>Download succeded</source>
        <translation type="vanished">Téléchargement effectué</translation>
    </message>
    <message>
        <source>[INFO] Yt-dlp command: </source>
        <translation>[INFO] Commande de yt-dlp&#xa0;: </translation>
    </message>
    <message>
        <source>[ERROR] QProcess failed with error code: </source>
        <translation>[ERROR] Le QProcess a échoué avec le code d’erreur&#xa0;: </translation>
    </message>
    <message>
        <source>Failed! Recheck input for errors. If the url you provided is correct, try with other resolutions or formats.</source>
        <translation>Le téléchargement a échoué. Si l’URL que vous avez fournie est correcte, réessayez avec d’autres résolutions ou formats.</translation>
    </message>
</context>
<context>
    <name>downloadStatus</name>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloading...</source>
        <translation>Téléchargement...</translation>
    </message>
</context>
<context>
    <name>ytdl</name>
    <message>
        <source>ytdl</source>
        <translation type="vanished">ytdl</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Music&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Musique&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Qualité:</translation>
    </message>
    <message>
        <source>Best</source>
        <translation>Meilleure</translation>
    </message>
    <message>
        <source>Good</source>
        <translation>Bonne</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Moyenne</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Basse</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <source>AAC</source>
        <translation>AAC</translation>
    </message>
    <message>
        <source>OGG</source>
        <translation>OGG</translation>
    </message>
    <message>
        <source>MP3</source>
        <translation>MP3</translation>
    </message>
    <message>
        <source>OPUS</source>
        <translation>OPUS</translation>
    </message>
    <message>
        <source>WAV</source>
        <translation>WAV</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vidéo</translation>
    </message>
    <message>
        <source>Max Resolution:</source>
        <translation>Résolution max:</translation>
    </message>
    <message>
        <source>4K</source>
        <translation>4K</translation>
    </message>
    <message>
        <source>1440p</source>
        <translation>1440p</translation>
    </message>
    <message>
        <source>1080p</source>
        <translation>1080p</translation>
    </message>
    <message>
        <source>720p</source>
        <translation>720p</translation>
    </message>
    <message>
        <source>480p</source>
        <translation>480p</translation>
    </message>
    <message>
        <source>360p</source>
        <translation>360p</translation>
    </message>
    <message>
        <source>Preferred Format:</source>
        <translation>Format préféré:</translation>
    </message>
    <message>
        <source>3GP</source>
        <translation>3GP</translation>
    </message>
    <message>
        <source>FLV</source>
        <translation>FLV</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>WEBM</source>
        <translation>WEBM</translation>
    </message>
    <message>
        <source>Enter URL:</source>
        <translation>Entrez l’URL:</translation>
    </message>
    <message>
        <source>Playlist</source>
        <translation>Playlist</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>Sélectionner le dossier...</translation>
    </message>
    <message>
        <source>Defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Télécharger</translation>
    </message>
    <message>
        <source>Yt Downloader</source>
        <translation>Téléchargeur de vidéos</translation>
    </message>
    <message>
        <source>Best quality audio, the file will be bigger than with other quality levels.</source>
        <translation>Meilleure qualité audio, le fichier sera plus gros qu&apos;avec qu&apos;avec les autres niveaux.</translation>
    </message>
    <message>
        <source>Lower quality audio, the file will be smaller than with other quality levels.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(Recommended for Apple’s systems) Small files but not universally supported and proprietary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(Recommended for open-source systems) Small files and good performances but not supported everywhere</source>
        <translation>(Recomendé pour les systèmes libres) Petits fichier et bonnes performances mais n&apos;est pas supporté partout</translation>
    </message>
    <message>
        <source>(Recommended for most system) Best compatibility and good audio quality</source>
        <translation>(Recommandé pour la plupart des systèmes) Meilleure compatibilité et bonne qualité audio</translation>
    </message>
    <message>
        <source>Better audio reproduction but large files and not supported everywhere</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Better audio reproduction but really large files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
